# QuantumEPR

Run a quantum simulation using Energy Participation Ratio (EPR) analysis.

This class orchestrates a distributed HFSS simulation, extracts participation data
for defined junctions, and computes the quantum `χ` (chi) matrix via numerical diagonalization.

The energy-participation-ratio method is based on:
**"Energy-participation quantization of Josephson circuits"**  
DOI: [10.1038/s41534-021-00461-8](https://doi.org/10.1038/s41534-021-00461-8)

::: quansys.simulation.quantum_epr.model.QuantumEPR

